==> gallery_1.5.orig.tar.gz: gallery-1.5.orig/locale/fr_FR/fr_FR-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: fr_FR-nls.php,v 1.9.2.3 2005/03/23 08:54:13 cryptographite Exp $
 *
 * Version: 1.5
 */
/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */


/**
 ** Native languagename
 **/
	$nls['language']['fr_FR'] = 'Fran&#231;ais'; // French

/**
 ** Alias for languages with different browser and gettext codes
 **/

	$nls['alias']['fr'] = 'fr_FR';

/**
 ** Aliases for languages which we substitte or send by NUKE or GeekLog
 **/

	$nls['alias']['french'] =		'fr_FR' ;
	$nls['alias']['fra'] =			'fr_FR' ;
	$nls['alias']['fr_BE'] = 		'fr_FR' ;
	$nls['alias']['fr_CA'] = 		'fr_FR' ;
	$nls['alias']['fr_LU'] = 		'fr_FR' ;
	$nls['alias']['fr_CH'] = 		'fr_FR' ;
	$nls['alias']['fr_FR.ISO8859-1'] =	'fr_FR' ;
	$nls['alias']['french_france'] =	'fr_FR' ;


/**
 ** phpNuke
 **/
	$nls['phpnuke']['fr_FR'] = 'french';

/**
 ** postNuke
 **/
	$nls['postnuke']['fr_FR'] = 'fra';
?>

==> gallery_1.5.1.orig.tar.gz: gallery-1.5.1.orig/locale/fr_FR/fr_FR-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: fr_FR-nls.php,v 1.13.2.2 2005/09/12 22:40:55 dmolavi Exp $
 */
 
/**
 * @version	1.5.1
 * @package	Languagepack
 * @subpackage	French
 */

/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz.
 * (jens@peino.de)
 */

/**
 * Native languagename
 */
	$nls['language']['fr_FR'] =		'Fran&#231;ais';

/**
 * Aliases for languages with different browser and gettext codes
 */
	$nls['alias']['fr'] =			'fr_FR';

/**
 * Aliases for languages which we substitte or send by NUKE, GeekLog or Mambo
 */
	$nls['alias']['french'] =		'fr_FR' ;
	$nls['alias']['fra'] =			'fr_FR' ;
	$nls['alias']['fr_BE'] = 		'fr_FR' ;
	$nls['alias']['fr_CA'] = 		'fr_FR' ;
	$nls['alias']['fr_LU'] = 		'fr_FR' ;
	$nls['alias']['fr_CH'] = 		'fr_FR' ;
	$nls['alias']['fr_FR.ISO8859-1'] =	'fr_FR' ;
	$nls['alias']['french_france'] =	'fr_FR' ;

/**
 * phpNuke
 */
	$nls['phpnuke']['fr_FR'] =		'french';

/**
 * postNuke
 */
	$nls['postnuke']['fr_FR'] =		'fra';

?>
